==> graphic-0.1.0.tar.gz: debug/lib/pages/chart_page.dart <==
import 'package:flutter/material.dart';
import 'package:graphic/graphic.dart' as graphic;

class ChartPage extends StatelessWidget {
  final GlobalKey<ScaffoldState> _scaffoldKey = new GlobalKey<ScaffoldState>();

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      key: _scaffoldKey,
      appBar: AppBar(
        title: Text('Chart'),
      ),
      backgroundColor: Colors.white,
      body: SingleChildScrollView(
        child: Center(
          child: Column(
            children: <Widget>[
              Container(
                width: 300,
                height: 300,
                child: graphic.Chart(
                  data: [
                    { 'genre': 'Sports', 'sold': 275 },
                    { 'genre': 'Strategy', 'sold': 115 },
                    { 'genre': 'Action', 'sold': 120 },
                    { 'genre': 'Shooter', 'sold': 350 },
                    { 'genre': 'Other', 'sold': 150 },
                  ],
                  scales: {
                    'genre': graphic.CatScale(
                      accessor: (map) => map['genre'] as String,
                    ),
                    'sold': graphic.NumScale(
                      accessor: (map) => map['sold'] as num,
                      nice: true,
                    )
                  },
                  geoms: [graphic.IntervalGeom(
                    position: graphic.PositionAttr(field: 'genre*sold'),
                  )],
                  axes: {
                    'genre': graphic.Defaults.horizontalAxis,
                    'sold': graphic.Defaults.verticalAxis,
                  },
                ),
                margin: EdgeInsets.all(20),
              ),
            ],
          ),
        ),
      ),
    );
  }
}

==> graphic-0.2.0.tar.gz: debug/lib/pages/chart_page.dart <==
import 'package:flutter/material.dart';
import 'package:graphic/graphic.dart' as graphic;

class ChartPage extends StatelessWidget {
  final GlobalKey<ScaffoldState> _scaffoldKey = new GlobalKey<ScaffoldState>();

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      key: _scaffoldKey,
      appBar: AppBar(
        title: Text('Chart'),
      ),
      backgroundColor: Colors.white,
      body: SingleChildScrollView(
        child: Center(
          child: Column(
            children: <Widget>[
              Container(
                width: 300,
                height: 300,
                child: graphic.Chart(
                  data: [
                    { 'genre': 'Sports', 'sold': 275 },
                    { 'genre': 'Strategy', 'sold': 115 },
                    { 'genre': 'Action', 'sold': 120 },
                    { 'genre': 'Shooter', 'sold': 350 },
                    { 'genre': 'Other', 'sold': 150 },
                  ],
                  scales: {
                    'genre': graphic.CatScale(
                      accessor: (map) => map['genre'] as String,
                    ),
                    'sold': graphic.LinearScale(
                      accessor: (map) => map['sold'] as num,
                      nice: true,
                    )
                  },
                  geoms: [graphic.IntervalGeom(
                    position: graphic.PositionAttr(field: 'genre*sold'),
                  )],
                  axes: {
                    'genre': graphic.Defaults.horizontalAxis,
                    'sold': graphic.Defaults.verticalAxis,
                  },
                ),
                margin: EdgeInsets.all(20),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
